pub fn prepare(
input: &str,
tool_result_max_chars: usize,
text_limit: usize,
) -> CompactPreparationExpand description
Render the conversation text into a serializable compact envelope.
pub fn prepare(
input: &str,
tool_result_max_chars: usize,
text_limit: usize,
) -> CompactPreparationRender the conversation text into a serializable compact envelope.